@@ -14,7 +14,16 @@ import logging
 logger = logging.getLogger(__name__)
 
 
+# class NewServerTest(unittest.TestCase):
+class NewServerTest(TmuxTestCase):
+
+    def test_hi(self):
+        self.assertEqual(2, 2)
+        sessions = t._sessions
+
+
 class ServerTest(TmuxTestCase):
+
     def test_has_session(self):
         self.assertTrue(t.has_session(self.TEST_SESSION_NAME))
         self.assertFalse(t.has_session('asdf2314324321'))
